story function

Story story(
  1. String text
)

A convenience lambda function that wraps the Story class constructor and call method to provide a more concise and readable entry point for creating BDD-style stories and test scenarios using the StoryD fluent API.

Implementation

Story story(String text) => Story(text);