Narrative constructor
Narrative(
- List<
StoryStepData> steps
Creates a text report generator from a static list of story steps.
Implementation
Narrative(this.steps);
Creates a text report generator from a static list of story steps.
Narrative(this.steps);