FunctionStepExt extension
Convenience extensions on functional primitives to initialize fluently chained steps.
- on
Properties
- step → StepInput
-
Available on Function, provided by the FunctionStepExt extension
Wraps the callback directly into a baseline, execution-ready StepInput container.no setter
Methods
-
expectException<
T extends Object> ([String? expectedMessage]) → StepInput -
Available on Function, provided by the FunctionStepExt extension
Configures a naked callback reference to expect a runtime exception of typeT. -
withParams(
dynamic newParams) → StepInput -
Available on Function, provided by the FunctionStepExt extension
Couples a raw callback signature directly with its concrete runtime data arguments.