hasFailed property
bool
get
hasFailed
Returns true if this specific result represents an execution failure state.
Implementation
bool get hasFailed => status == StepStatus.failed;
Returns true if this specific result represents an execution failure state.
bool get hasFailed => status == StepStatus.failed;