ScenarioStep class

Base class used for all scenario steps

This class is never instantiated directly, but serves as a common type for use in scenario step lists.

Inheritance
Implementers

Constructors

ScenarioStep(StoryContext context)

Properties

asStory Story
no setterinherited
context StoryContext
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited