StoryStep class

Base class used for all story steps

This class is never instantiated directly, but serves as a common type for use in narrative lists.

Implementers

Constructors

StoryStep(StoryContext context)

Properties

asStory Story
no setter
context StoryContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited