AsA class

Represents the Persona or Role phase of the narrative.

Captures who wants or benefits from the feature.

Inheritance

Constructors

AsA(StoryContext context)

Properties

asStory Story
no setterinherited
context StoryContext
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

iCan(String action) ICan
Transitions to the feature requirement step.
iWant(String feature) IWant
Transitions to the capability step.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withScenario(String description) Scenario
Concludes the narrative and moves to scenario definition.

Operators

operator ==(Object other) bool
The equality operator.
inherited