Scenario class

The bridge between the high-level story narrative and concrete test cases.

Starts a new acceptance criteria scenario within the current story. Scenario also wraps a Dart test() instance so that tests will execute normally using existing tooling within an IDE, as well as working nicely with Dart test API's startup and shutdown methods.

Inheritance

Constructors

Scenario(StoryContext builder)

Properties

asStory Story
no setterinherited
context StoryContext
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

given(StepInput step) GivenScenario
Sets up the initial state or preconditions for this scenario.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
then(StepInput step) ThenScenario
Defines the expected outcome or postcondition of the scenario.
toString() String
A string representation of this object.
inherited
when(StepInput step) WhenScenario
Defines the key action or event that triggers the scenario behavior.

Operators

operator ==(Object other) bool
The equality operator.
inherited