withScenario method

Scenario withScenario(
  1. String value
)

Concludes the current scenario and begins a brand new scenario block.

Permits an optional shortcut to move directly to the next scenario without needing to implement an intermediary step that might otherwise do nothing.

Example: .withScenario('User attempts duplicate email login')

Implementation

Scenario withScenario(String value) {
  context.builder.addNarrativeStep(ScenarioStepData(value));
  return Scenario(context);
}