StringStepExt extension
Convenience extensions on string literals to initialize fluently chained steps.
- on
Properties
- step → StepInput
-
Available on String, provided by the StringStepExt extension
Wraps the plain text string into a baseline, purely descriptive StepInput wrapper.no setter
Methods
-
withCallback(
Function fn) → StepInput -
Available on String, provided by the StringStepExt extension
Pairs a descriptive string milestone directly with its target execution callback logic.