fluent/core/story
library
Classes
-
Story
-
This class is the heart of the StoryD fluent API. It is both the entry point
for creating BDD-style stories and test scenarios, and the execution point
for running tests and generating test reports. It also behaves as a wrapper
for a Dart test's
Group() method, ensuring all of the story's test scenarios
are kept together during test execution.
-
StoryContext
-
A proxy class that allows Story and StoryBuilder objects to be passed along
the fluent DSL without the need to write overly complex traversal code.