Because class
Represents the Justification phase of the narrative.
Captures explicit reasoning or compliance needs behind a requirement.
Constructors
- Because(StoryContext context)
Properties
- asStory → Story
-
no setterinherited
- context → StoryContext
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withScenario(
String description) → Scenario - Concludes the narrative and moves to scenario definition.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited