When class
Represents the Situation phase of the narrative.
Captures the context or triggering condition in a Situation-Motivation-Outcome story.
Constructors
- When(StoryContext context)
Properties
- asStory → Story
-
no setterinherited
- context → StoryContext
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
iWant(
String motivation) → IWant - Transitions to the motivation phase driven by this situation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited